@@ -1,7 +1,6 @@
 import os
 import glob
 import gzip
-import logging
 from pathlib import Path
 from multiprocessing import Pool
 from hypergol.base_task import BaseTask
@@ -64,7 +63,7 @@ class Task(BaseTask):
         """
         self.outputDataset.delete()
         jobs = [
-            (chunk, self.__class__.__name__, k, self.outputDataset.chunkCount)
+            (chunk, self.__class__.__name__, k, self.outputDataset.chunkCount, self.logger)
             for k, chunk in enumerate(self.outputDataset.get_data_chunks(mode='w'))
         ]
         if threads == 0:
@@ -95,9 +94,8 @@ def _merge_function(args):
 
     Returns the checksum so the caller can create the ``.chk`` file.
     """
-    chunk, name, k, total = args
-    logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(message)s')
-    logging.info(f'{name} - {k:3}/{total:3} - finish - START')
+    chunk, name, k, total, logger = args
+    logger.log(f'{name} - {k:3}/{total:3} - finish - START')
     chunk.open()
     pattern = str(Path(
         chunk.dataset.location, chunk.dataset.project, f'{chunk.dataset.name}_temp',
@@ -107,5 +105,5 @@ def _merge_function(args):
         with gzip.open(filePath, 'rt') as inputFile:
             for line in inputFile:
                 chunk.write(line)
-    logging.info(f'{name} - {k:3}/{total:3} - finish - END')
+    logger.log(f'{name} - {k:3}/{total:3} - finish - END')
     return chunk.close()
